@@ -3,7 +3,7 @@ from typing import List, Tuple
 from .asyncio_connection import AsyncConnection
 from .client import Client
 from .constants import Step, Namespace, FESL_DETAILS, Platform, LookupType, DEFAULT_LEADERBOARD_KEYS, STATS_KEYS
-from .exceptions import PyBfbc2StatsNotFoundError
+from .exceptions import PyBfbc2StatsNotFoundError, PyBfbc2StatsLoginError
 
 
 class AsyncClient(Client):
@@ -19,39 +19,59 @@ class AsyncClient(Client):
         return self
 
     async def __aexit__(self, *excinfo):
+        await self.logout()
         await self.connection.close()
 
     async def hello(self) -> bytes:
-        if self.track_steps and Step.hello in self.complete_steps:
-            return b''
+        if self.track_steps and Step.hello in self.completed_steps:
+            return self.completed_steps[Step.hello]
 
-        hello_packet = self.get_hello_packet()
+        hello_packet = self.build_hello_packet()
         await self.connection.write(hello_packet)
-        self.complete_steps.append(Step.hello)
-        return await self.connection.read()
 
-    async def memcheck(self) -> bytes:
-        if self.track_steps and Step.memcheck in self.complete_steps:
-            return b''
-        elif self.track_steps and Step.hello not in self.complete_steps:
-            await self.hello()
+        # FESL sends hello response immediately followed initial memcheck => read both and return hello response
+        response = await self.connection.read()
+        _ = await self.connection.read()
 
-        memcheck_packet = self.get_memcheck_packet()
+        self.completed_steps[Step.hello] = hello_packet
+
+        # Reply to initial memcheck
+        await self.memcheck()
+
+        return response
+
+    async def memcheck(self) -> None:
+        memcheck_packet = self.build_memcheck_packet()
         await self.connection.write(memcheck_packet)
-        self.complete_steps.append(Step.memcheck)
-        return await self.connection.read()
 
     async def login(self) -> bytes:
-        if self.track_steps and Step.login in self.complete_steps:
-            return b''
-        elif self.track_steps and Step.memcheck not in self.complete_steps:
-            await self.memcheck()
+        if self.track_steps and Step.login in self.completed_steps:
+            return self.completed_steps[Step.login]
+        elif self.track_steps and Step.hello not in self.completed_steps:
+            await self.hello()
 
         login_packet = self.build_login_packet(self.username, self.password)
         await self.connection.write(login_packet)
-        self.complete_steps.append(Step.login)
+        response = await self.connection.read()
+
+        response_valid, error_message = self.is_valid_login_response(response)
+        if not response_valid:
+            raise PyBfbc2StatsLoginError(error_message)
+
+        self.completed_steps[Step.login] = response
+
+        return response
+
+    async def logout(self) -> bytes:
+        logout_packet = self.build_logout_packet()
+        await self.connection.write(logout_packet)
+        self.completed_steps.clear()
         return await self.connection.read()
 
+    async def ping(self) -> None:
+        ping_packet = self.build_ping_packet()
+        await self.connection.write(ping_packet)
+
     async def lookup_usernames(self, usernames: List[str], namespace: Namespace) -> List[dict]:
         return await self.lookup_user_identifiers(usernames, namespace, LookupType.byName)
 
@@ -67,7 +87,7 @@ class AsyncClient(Client):
 
     async def lookup_user_identifiers(self, identifiers: List[str], namespace: Namespace,
                                       lookup_type: LookupType) -> List[dict]:
-        if self.track_steps and Step.login not in self.complete_steps:
+        if self.track_steps and Step.login not in self.completed_steps:
             await self.login()
 
         lookup_packet = self.build_user_lookup_packet(identifiers, namespace, lookup_type)
@@ -85,7 +105,7 @@ class AsyncClient(Client):
         return results.pop()
 
     async def search_name(self, screen_name: str) -> dict:
-        if self.track_steps and Step.login not in self.complete_steps:
+        if self.track_steps and Step.login not in self.completed_steps:
             await self.login()
 
         search_packet = self.build_search_packet(screen_name)
@@ -95,7 +115,7 @@ class AsyncClient(Client):
         return self.format_search_response(parsed_response, metadata)
 
     async def get_stats(self, userid: int, keys: List[bytes] = STATS_KEYS) -> dict:
-        if self.track_steps and Step.login not in self.complete_steps:
+        if self.track_steps and Step.login not in self.completed_steps:
             await self.login()
 
         # Send query in chunks
@@ -108,7 +128,7 @@ class AsyncClient(Client):
 
     async def get_leaderboard(self, min_rank: int = 1, max_rank: int = 50, sort_by: bytes = b'score',
                               keys: List[bytes] = DEFAULT_LEADERBOARD_KEYS) -> List[dict]:
-        if self.track_steps and Step.login not in self.complete_steps:
+        if self.track_steps and Step.login not in self.completed_steps:
             await self.login()
 
         leaderboard_packet = self.build_leaderboard_query_packet(min_rank, max_rank, sort_by, keys)
@@ -124,7 +144,14 @@ class AsyncClient(Client):
         last_packet = False
         while not last_packet:
             packet = await self.connection.read()
-            data, last_packet = self.handle_stats_response_packet(packet, list_parse_prefix + b'[]=')
-            response += data
+            if b'TXN=MemCheck' in packet:
+                # Respond to memcheck
+                await self.memcheck()
+            elif b'TXN=Ping' in packet:
+                # Respond to ping
+                await self.ping()
+            else:
+                data, last_packet = self.handle_stats_response_packet(packet, list_parse_prefix + b'[]=')
+                response += data
 
         return self.parse_list_response(response, list_parse_prefix)
