@@ -3,14 +3,14 @@ from enum import Enum
 
 class Step(int, Enum):
     hello = 1
-    memcheck = 2
-    login = 3
+    login = 2
 
 
 class Namespace(bytes, Enum):
     pc = b'battlefield'
     xbox360 = b'xbox'
     ps3 = b'ps3'
+    cem_ea_id = b'cem_ea_id'
 
 
 class LookupType(bytes, Enum):
@@ -49,105 +49,104 @@ STATS_KEYS = [b'accuracy', b'br40mmgl_00', b'br40mmgl_01', b'br40mmsg_00', b'br4
               b'brm1_01', b'brm1a1_00', b'brm1a1_01', b'brm21v_00', b'brm21v_01', b'brm249_00', b'brm249_01',
               b'brm24_00', b'brm24_01', b'brm2cg_00', b'brm2cg_01', b'brm2v_00', b'brm2v_01', b'brm40v_00',
               b'brm40v_01', b'brm416_00', b'brm416_01', b'brm60_00', b'brm60_01', b'brm60v_00', b'brm60v_01',
-              b'brm93r_00', b'brm93r_01', b'brm95_00', b'brm95_01', b'brm95k_00', b'brm95k_01', b'brm9_00',
-              b'brm9_01', b'brmac10v_00', b'brmac10v_01', b'brmcs_00', b'brmcs_01', b'brmel_00', b'brmel_01',
-              b'brmg36_00', b'brmg36_01', b'brmg3_00', b'brmg3_01', b'brmg3k_00', b'brmg3k_01', b'brmk14ebr_00',
-              b'brmk14ebr_01', b'brmp412_00', b'brmp412_01', b'brmst_00', b'brmst_01', b'brn2k_00', b'brn2k_01',
-              b'brpkm_00', b'brpkm_01', b'brpp2_00', b'brpp2_01', b'brppshv_00', b'brppshv_01', b'brqbu88_00',
-              b'brqbu88_01', b'brqju88_00', b'brqju88_01', b'brrpg7_00', b'brrpg7_01', b'brrpkv_00', b'brrpkv_01',
-              b'brs12k_00', b'brs12k_01', b'brscar_00', b'brscar_01', b'brsea_00', b'brsea_01', b'brspas12_00',
-              b'brspas12_01', b'brstav_00', b'brstav_01', b'brsv98_00', b'brsv98_01', b'brsvdv_00', b'brsvdv_01',
-              b'brsvu_00', b'brsvu_01', b'brtt33v_00', b'brtt33v_01', b'brtveh_00', b'brtveh_01', b'bru12_00',
-              b'bru12_01', b'brump_00', b'brump_01', b'brumpk_00', b'brumpk_01', b'bruzi_00', b'bruzi_01', b'brvss_00',
-              b'brvss_01', b'brxm22v_00', b'brxm22v_01', b'brxm8_00', b'brxm8_01', b'brxm8c_00', b'brxm8c_01',
-              b'brxm8lmg_00', b'brxm8lmg_01', b'c_40mmgl__kw_g', b'c_40mmgl__sfw_g', b'c_40mmgl__shw_g',
-              b'c_40mmgl__sw_g', b'c_40mmsg__kw_g', b'c_40mmsg__sfw_g', b'c_40mmsg__shw_g', b'c_40mmsg__sw_g',
-              b'c_9a91__kw_g', b'c_9a91__sfw_g', b'c_9a91__shw_g', b'c_9a91__sw_g', b'c_KORD__si_g', b'c_KORN__si_g',
-              b'c_MI28__ddw_g', b'c_MI28__si_g', b'c_PBLB__ddw_g', b'c_PBLB__si_g', b'c_QLZ8__si_g', b'c_TOW2__si_g',
-              b'c_VADS__si_g', b'c_XM307__si_g', b'c_XM312__si_g', b'c__40mmgl_hsh_g', b'c__40mmsg_hsh_g',
-              b'c__9a91_hsh_g', b'c__KORD_ki_g', b'c__KORN_ki_g', b'c__MI28_ki_g', b'c__PBLB_ki_g', b'c__QLZ8_ki_g',
-              b'c__TOW2_ki_g', b'c__VADS_ki_g', b'c__XM307_ki_g', b'c__XM312_ki_g', b'c___h_g', b'c___msa_g',
-              b'c___r_g', b'c___res_g', b'c___rev_g', b'c___tag_g', b'c__aav_ki_g', b'c__aaw_hsh_g', b'c__aek_hsh_g',
-              b'c__ah60_ki_g', b'c__ah64_ki_g', b'c__ak47v_hsh_g', b'c__aks74u_hsh_g', b'c__an94_hsh_g', b'c__as_ko_g',
-              b'c__aug_hsh_g', b'c__bmd3_ki_g', b'c__bmda_ki_g', b'c__boaw_hsh_g', b'c__cav_ki_g', b'c__cobr_ki_g',
-              b'c__de_ko_g', b'c__defi_hsh_g', b'c__f2000_hsh_g', b'c__g3_hsh_g', b'c__gaz69v_ki_g', b'c__gol_hsh_g',
-              b'c__havoc_ki_g', b'c__helw_hsh_g', b'c__hmv_ki_g', b'c__hueyv_ki_g', b'c__jets_ki_g', b'c__m15v_ki_g',
-              b'c__m16_hsh_g', b'c__m16a1v_hsh_g', b'c__m16k_hsh_g', b'c__m1911_hsh_g', b'c__m1_hsh_g',
-              b'c__m1a1_hsh_g', b'c__m1a2_ki_g', b'c__m21v_hsh_g', b'c__m249_hsh_g', b'c__m24_hsh_g', b'c__m2v_hsh_g',
-              b'c__m3a3_ki_g', b'c__m40v_hsh_g', b'c__m416_hsh_g', b'c__m48v_ki_g', b'c__m60_hsh_g', b'c__m60v_hsh_g',
-              b'c__m93r_hsh_g', b'c__m95_hsh_g', b'c__m95k_hsh_g', b'c__m9_hsh_g', b'c__mac10v_hsh_g', b'c__mcs_hsh_g',
-              b'c__mg36_hsh_g', b'c__mg3_hsh_g', b'c__mg3k_hsh_g', b'c__mk14ebr_hsh_g', b'c__mp412_hsh_g',
-              b'c__n2k_hsh_g', b'c__pbrv_ki_g', b'c__pkm_hsh_g', b'c__pp2_hsh_g', b'c__ppshv_hsh_g', b'c__prtg_hsh_g',
-              b'c__qbu88_hsh_g', b'c__qju88_hsh_g', b'c__quad_ki_g', b'c__re_ko_g', b'c__rept_hsh_g', b'c__rpkv_hsh_g',
-              b'c__s12k_hsh_g', b'c__scar_hsh_g', b'c__smol_hsh_g', b'c__spas12_hsh_g', b'c__stgl_hsh_g',
-              b'c__stmg_hsh_g', b'c__su_ko_g', b'c__sv98_hsh_g', b'c__svdv_hsh_g', b'c__svu_hsh_g', b'c__t54v_ki_g',
-              b'c__t90_ki_g', b'c__tanc_hsh_g', b'c__tanm_hsh_g', b'c__tt33v_hsh_g', b'c__u12_hsh_g', b'c__uav_ki_g',
-              b'c__ump_hsh_g', b'c__umpk_hsh_g', b'c__uzi_hsh_g', b'c__vodn_ki_g', b'c__vss_hsh_g', b'c__xm22v_hsh_g',
-              b'c__xm8_hsh_g', b'c__xm8c_hsh_g', b'c__xm8lmg_hsh_g', b'c_aav__si_g', b'c_aaw__kw_g', b'c_aek__kw_g',
-              b'c_aek__sfw_g', b'c_aek__shw_g', b'c_aek__sw_g', b'c_ah60__ddw_g', b'c_ah60__si_g', b'c_ah64__ddw_g',
-              b'c_ah64__si_g', b'c_ak47v__kw_g', b'c_ak47v__sfw_g', b'c_ak47v__shw_g', b'c_ak47v__sw_g',
-              b'c_aks74u__kw_g', b'c_aks74u__sfw_g', b'c_aks74u__shw_g', b'c_aks74u__sw_g', b'c_ammb__kw_g',
-              b'c_ammb__sfw_g', b'c_ammb__shw_g', b'c_ammb__sw_g', b'c_an94__kw_g', b'c_an94__sfw_g', b'c_an94__shw_g',
-              b'c_an94__sw_g', b'c_as__da_g', b'c_atm__kw_g', b'c_atm__sfw_g', b'c_atm__shw_g', b'c_atm__sw_g',
-              b'c_aug__kw_g', b'c_aug__sfw_g', b'c_aug__shw_g', b'c_aug__sw_g', b'c_bmd3__ddw_g', b'c_bmd3__si_g',
-              b'c_bmda__ddw_g', b'c_bmda__si_g', b'c_boaw__kw_g', b'c_br40mmgl_40mmgl__kw_g',
-              b'c_br40mmsg_40mmsg__kw_g',b'c_br9a91_9a91__kw_g', b'c_braek_aek__kw_g', b'c_brair__air_ki_g',
-              b'c_brak47v_ak47v__kw_g', b'c_braks74u_aks74u__kw_g', b'c_bran94_an94__kw_g', b'c_brarm__arm_ki_g',
-              b'c_bratm_atm__kw_g', b'c_braug_aug__kw_g', b'c_brc4_c4__kw_g', b'c_brf2000_f2000__kw_g',
-              b'c_brg3_g3__kw_g', b'c_brgol_gol__kw_g', b'c_brhgr_hgr__kw_g', b'c_brm136_m136__kw_g',
-              b'c_brm16_m16__kw_g', b'c_brm16a1v_m16a1v__kw_g', b'c_brm16k_m16k__kw_g', b'c_brm1911_m1911__kw_g',
-              b'c_brm1_m1__kw_g', b'c_brm1a1_m1a1__kw_g', b'c_brm21v_m21v__kw_g', b'c_brm249_m249__kw_g',
-              b'c_brm24_m24__kw_g', b'c_brm2cg_m2cg__kw_g', b'c_brm2v_m2v__kw_g', b'c_brm40v_m40v__kw_g',
-              b'c_brm416_m416__kw_g', b'c_brm60_m60__kw_g', b'c_brm60v_m60v__kw_g', b'c_brm93r_m93r__kw_g',
-              b'c_brm95_m95__kw_g', b'c_brm95k_m95k__kw_g', b'c_brm9_m9__kw_g', b'c_brmac10v_mac10v__kw_g',
-              b'c_brmcs_mcs__kw_g', b'c_brmel_mel__kw_g', b'c_brmg36_mg36__kw_g', b'c_brmg3_mg3__kw_g',
-              b'c_brmg3k_mg3k__kw_g', b'c_brmk14ebr_mk14ebr__kw_g', b'c_brmp412_mp412__kw_g', b'c_brmst_mst__kw_g',
-              b'c_brn2k_n2k__kw_g', b'c_brpkm_pkm__kw_g', b'c_brpp2_pp2__kw_g', b'c_brppshv_ppshv__kw_g',
-              b'c_brqbu88_qbu88__kw_g', b'c_brqju88_qju88__kw_g', b'c_brrpg7_rpg7__kw_g', b'c_brrpkv_rpkv__kw_g',
-              b'c_brs12k_s12k__kw_g', b'c_brscar_scar__kw_g', b'c_brsea__sea_ki_g', b'c_brspas12_spas12__kw_g',
-              b'c_brstav__stav_ki_g', b'c_brsv98_sv98__kw_g', b'c_brsvdv_svdv__kw_g', b'c_brsvu_svu__kw_g',
-              b'c_brtt33v_tt33v__kw_g', b'c_brtveh__tveh_ki_g', b'c_bru12_u12__kw_g', b'c_brump_ump__kw_g',
-              b'c_brumpk_umpk__kw_g', b'c_bruzi_uzi__kw_g', b'c_brvss_vss__kw_g', b'c_brxm22v_xm22v__kw_g',
-              b'c_brxm8_xm8__kw_g', b'c_brxm8c_xm8c__kw_g', b'c_brxm8lmg_xm8lmg__kw_g', b'c_c4__kw_g', b'c_c4__sfw_g',
-              b'c_c4__shw_g', b'c_c4__sw_g', b'c_cav__ddw_g', b'c_cav__si_g', b'c_cobr__ddw_g', b'c_cobr__si_g',
-              b'c_de__da_g', b'c_defi__kw_g', b'c_defi__sfw_g', b'c_defi__shw_g', b'c_defi__sw_g', b'c_deml__kw_g',
-              b'c_di01_m16k__kw_g', b'c_di02_umpk__kw_g', b'c_di03_mg3k__kw_g', b'c_di04_m95k__kw_g', b'c_f2000__kw_g',
-              b'c_f2000__sfw_g', b'c_f2000__shw_g', b'c_f2000__sw_g', b'c_g3__kw_g', b'c_g3__sfw_g', b'c_g3__shw_g',
-              b'c_g3__sw_g', b'c_gaz69v__ddw_g', b'c_gaz69v__si_g', b'c_go40mmgl_40mmgl__kw_g',
-              b'c_go40mmsg_40mmsg__kw_g', b'c_go9a91_9a91__kw_g', b'c_goaek_aek__kw_g', b'c_goair__air_ki_g',
-              b'c_goak47v_ak47v__kw_g', b'c_goaks74u_aks74u__kw_g', b'c_goan94_an94__kw_g', b'c_goarm__arm_ki_g',
-              b'c_goatm_atm__kw_g', b'c_goaug_aug__kw_g', b'c_goc4_c4__kw_g', b'c_gof2000_f2000__kw_g',
-              b'c_gog3_g3__kw_g', b'c_gogol_gol__kw_g', b'c_gohgr_hgr__kw_g', b'c_gol__kw_g', b'c_gol__sfw_g',
-              b'c_gol__shw_g', b'c_gol__sw_g', b'c_gom136_m136__kw_g', b'c_gom16_m16__kw_g', b'c_gom16a1v_m16a1v__kw_g',
-              b'c_gom16k_m16k__kw_g', b'c_gom1911_m1911__kw_g', b'c_gom1_m1__kw_g', b'c_gom1a1_m1a1__kw_g',
-              b'c_gom21v_m21v__kw_g', b'c_gom249_m249__kw_g', b'c_gom24_m24__kw_g', b'c_gom2cg_m2cg__kw_g',
-              b'c_gom2v_m2v__kw_g', b'c_gom40v_m40v__kw_g', b'c_gom416_m416__kw_g', b'c_gom60_m60__kw_g',
-              b'c_gom60v_m60v__kw_g', b'c_gom93r_m93r__kw_g', b'c_gom95_m95__kw_g', b'c_gom95k_m95k__kw_g',
-              b'c_gom9_m9__kw_g', b'c_gomac10v_mac10v__kw_g', b'c_gomcs_mcs__kw_g', b'c_gomel_mel__kw_g',
-              b'c_gomg36_mg36__kw_g', b'c_gomg3_mg3__kw_g', b'c_gomg3k_mg3k__kw_g', b'c_gomk14ebr_mk14ebr__kw_g',
-              b'c_gomp412_mp412__kw_g', b'c_gomst_mst__kw_g', b'c_gon2k_n2k__kw_g', b'c_gopkm_pkm__kw_g',
-              b'c_gopp2_pp2__kw_g', b'c_goppshv_ppshv__kw_g', b'c_goqbu88_qbu88__kw_g', b'c_goqju88_qju88__kw_g',
-              b'c_gorpg7_rpg7__kw_g', b'c_gorpkv_rpkv__kw_g', b'c_gos12k_s12k__kw_g', b'c_goscar_scar__kw_g',
-              b'c_gosea__sea_ki_g', b'c_gospas12_spas12__kw_g', b'c_gostav__stav_ki_g', b'c_gosv98_sv98__kw_g',
-              b'c_gosvdv_svdv__kw_g', b'c_gosvu_svu__kw_g', b'c_gott33v_tt33v__kw_g', b'c_gotveh__tveh_ki_g',
-              b'c_gou12_u12__kw_g', b'c_goump_ump__kw_g', b'c_goumpk_umpk__kw_g', b'c_gouzi_uzi__kw_g',
-              b'c_govss_vss__kw_g', b'c_goxm22v_xm22v__kw_g', b'c_goxm8_xm8__kw_g', b'c_goxm8c_xm8c__kw_g',
-              b'c_goxm8lmg_xm8lmg__kw_g', b'c_havoc__ddw_g', b'c_havoc__si_g', b'c_helw__kw_g', b'c_hgr__kw_g',
-              b'c_hgr__sfw_g', b'c_hgr__shw_g', b'c_hgr__sw_g', b'c_hmv__ddw_g', b'c_hmv__si_g', b'c_hueyv__ddw_g',
-              b'c_hueyv__si_g', b'c_i01___hsh_g', b'c_i02_hg__kw_g', b'c_i03_hgr__kw_g', b'c_i04_mel__kw_g',
-              b'c_i05_mel__kw_g', b'c_i06___d_g', b'c_i07_ass__kw_g', b'c_i08_sup__kw_g', b'c_i09___vd_g',
-              b'c_i10___tag_g', b'c_i11___kn_g', b'c_i11___nik_g', b'c_i12_re_rec_lrh_g', b'c_i13_c4__kw_g',
-              b'c_i14_rec__kw_g', b'c_i15_dem__kw_g', b'c_i16___h_g', b'c_i17___res_g', b'c_i18___msa_g',
-              b'c_i19___r_g', b'c_i20___ko_g', b'c_i23_spe__kw_g', b'c_i24_atm__kw_g', b'c_i25___dok_g',
-              b'c_i26___hsh_g', b'c_i27___sa_g', b'c_i28___sa_g', b'c_i29___sa_g', b'c_i30___fc_g', b'c_i31___bd_g',
-              b'c_i38_mst__kw_g', b'c_i43___sqs_g', b'c_i44___sqres_g', b'c_i45___sqrep_g', b'c_i46___sqh_g',
-              b'c_i46___sqrev_g', b'c_i47___sqmsa_g', b'c_i48___ss_g', b'c_i49___sqa_g', b'c_i49___sqs_g',
-              b'c_i50___sqaob_g', b'c_i50___sqdob_g', b'c_jets__ddw_g', b'c_jets__si_g', b'c_knv__kw_g',
-              b'c_knv__sfw_g', b'c_knv__shw_g', b'c_knv__sw_g', b'c_kuro__ddw_g', b'c_kuro__si_g', b'c_loss_att_out_g',
-              b'c_loss_def_out_g', b'c_m136__kw_g', b'c_m136__sfw_g', b'c_m136__shw_g', b'c_m136__sw_g',
-              b'c_m14v__sw_g', b'c_m15v__ddw_g', b'c_m15v__si_g', b'c_m16__kw_g', b'c_m16__sfw_g', b'c_m16__shw_g',
-              b'c_m16__sw_g', b'c_m16a1v__kw_g', b'c_m16a1v__sfw_g', b'c_m16a1v__shw_g', b'c_m16a1v__sw_g',
-              b'c_m16k__kw_g', b'c_m16k__sfw_g', b'c_m16k__shw_g', b'c_m16k__sw_g', b'c_m1911__kw_g',
+              b'brm93r_00', b'brm93r_01', b'brm95_00', b'brm95_01', b'brm95k_00', b'brm95k_01', b'brm9_00', b'brm9_01',
+              b'brmac10v_00', b'brmac10v_01', b'brmcs_00', b'brmcs_01', b'brmel_00', b'brmel_01', b'brmg36_00',
+              b'brmg36_01', b'brmg3_00', b'brmg3_01', b'brmg3k_00', b'brmg3k_01', b'brmk14ebr_00', b'brmk14ebr_01',
+              b'brmp412_00', b'brmp412_01', b'brmst_00', b'brmst_01', b'brn2k_00', b'brn2k_01', b'brpkm_00',
+              b'brpkm_01', b'brpp2_00', b'brpp2_01', b'brppshv_00', b'brppshv_01', b'brqbu88_00', b'brqbu88_01',
+              b'brqju88_00', b'brqju88_01', b'brrpg7_00', b'brrpg7_01', b'brrpkv_00', b'brrpkv_01', b'brs12k_00',
+              b'brs12k_01', b'brscar_00', b'brscar_01', b'brsea_00', b'brsea_01', b'brspas12_00', b'brspas12_01',
+              b'brstav_00', b'brstav_01', b'brsv98_00', b'brsv98_01', b'brsvdv_00', b'brsvdv_01', b'brsvu_00',
+              b'brsvu_01', b'brtt33v_00', b'brtt33v_01', b'brtveh_00', b'brtveh_01', b'bru12_00', b'bru12_01',
+              b'brump_00', b'brump_01', b'brumpk_00', b'brumpk_01', b'bruzi_00', b'bruzi_01', b'brvss_00', b'brvss_01',
+              b'brxm22v_00', b'brxm22v_01', b'brxm8_00', b'brxm8_01', b'brxm8c_00', b'brxm8c_01', b'brxm8lmg_00',
+              b'brxm8lmg_01', b'c_40mmgl__kw_g', b'c_40mmgl__sfw_g', b'c_40mmgl__shw_g', b'c_40mmgl__sw_g',
+              b'c_40mmsg__kw_g', b'c_40mmsg__sfw_g', b'c_40mmsg__shw_g', b'c_40mmsg__sw_g', b'c_9a91__kw_g',
+              b'c_9a91__sfw_g', b'c_9a91__shw_g', b'c_9a91__sw_g', b'c_KORD__si_g', b'c_KORN__si_g', b'c_MI28__ddw_g',
+              b'c_MI28__si_g', b'c_PBLB__ddw_g', b'c_PBLB__si_g', b'c_QLZ8__si_g', b'c_TOW2__si_g', b'c_VADS__si_g',
+              b'c_XM307__si_g', b'c_XM312__si_g', b'c__40mmgl_hsh_g', b'c__40mmsg_hsh_g', b'c__9a91_hsh_g',
+              b'c__KORD_ki_g', b'c__KORN_ki_g', b'c__MI28_ki_g', b'c__PBLB_ki_g', b'c__QLZ8_ki_g', b'c__TOW2_ki_g',
+              b'c__VADS_ki_g', b'c__XM307_ki_g', b'c__XM312_ki_g', b'c___h_g', b'c___msa_g', b'c___r_g', b'c___res_g',
+              b'c___rev_g', b'c___tag_g', b'c__aav_ki_g', b'c__aaw_hsh_g', b'c__aek_hsh_g', b'c__ah60_ki_g',
+              b'c__ah64_ki_g', b'c__ak47v_hsh_g', b'c__aks74u_hsh_g', b'c__an94_hsh_g', b'c__as_ko_g', b'c__aug_hsh_g',
+              b'c__bmd3_ki_g', b'c__bmda_ki_g', b'c__boaw_hsh_g', b'c__cav_ki_g', b'c__cobr_ki_g', b'c__de_ko_g',
+              b'c__defi_hsh_g', b'c__f2000_hsh_g', b'c__g3_hsh_g', b'c__gaz69v_ki_g', b'c__gol_hsh_g', b'c__havoc_ki_g',
+              b'c__helw_hsh_g', b'c__hmv_ki_g', b'c__hueyv_ki_g', b'c__jets_ki_g', b'c__m15v_ki_g', b'c__m16_hsh_g',
+              b'c__m16a1v_hsh_g', b'c__m16k_hsh_g', b'c__m1911_hsh_g', b'c__m1_hsh_g', b'c__m1a1_hsh_g',
+              b'c__m1a2_ki_g', b'c__m21v_hsh_g', b'c__m249_hsh_g', b'c__m24_hsh_g', b'c__m2v_hsh_g', b'c__m3a3_ki_g',
+              b'c__m40v_hsh_g', b'c__m416_hsh_g', b'c__m48v_ki_g', b'c__m60_hsh_g', b'c__m60v_hsh_g', b'c__m93r_hsh_g',
+              b'c__m95_hsh_g', b'c__m95k_hsh_g', b'c__m9_hsh_g', b'c__mac10v_hsh_g', b'c__mcs_hsh_g', b'c__mg36_hsh_g',
+              b'c__mg3_hsh_g', b'c__mg3k_hsh_g', b'c__mk14ebr_hsh_g', b'c__mp412_hsh_g', b'c__n2k_hsh_g',
+              b'c__pbrv_ki_g', b'c__pkm_hsh_g', b'c__pp2_hsh_g', b'c__ppshv_hsh_g', b'c__prtg_hsh_g', b'c__qbu88_hsh_g',
+              b'c__qju88_hsh_g', b'c__quad_ki_g', b'c__re_ko_g', b'c__rept_hsh_g', b'c__rpkv_hsh_g', b'c__s12k_hsh_g',
+              b'c__scar_hsh_g', b'c__smol_hsh_g', b'c__spas12_hsh_g', b'c__stgl_hsh_g', b'c__stmg_hsh_g', b'c__su_ko_g',
+              b'c__sv98_hsh_g', b'c__svdv_hsh_g', b'c__svu_hsh_g', b'c__t54v_ki_g', b'c__t90_ki_g', b'c__tanc_hsh_g',
+              b'c__tanm_hsh_g', b'c__tt33v_hsh_g', b'c__u12_hsh_g', b'c__uav_ki_g', b'c__ump_hsh_g', b'c__umpk_hsh_g',
+              b'c__uzi_hsh_g', b'c__vodn_ki_g', b'c__vss_hsh_g', b'c__xm22v_hsh_g', b'c__xm8_hsh_g', b'c__xm8c_hsh_g',
+              b'c__xm8lmg_hsh_g', b'c_aav__si_g', b'c_aaw__kw_g', b'c_aek__kw_g', b'c_aek__sfw_g', b'c_aek__shw_g',
+              b'c_aek__sw_g', b'c_ah60__ddw_g', b'c_ah60__si_g', b'c_ah64__ddw_g', b'c_ah64__si_g', b'c_ak47v__kw_g',
+              b'c_ak47v__sfw_g', b'c_ak47v__shw_g', b'c_ak47v__sw_g', b'c_aks74u__kw_g', b'c_aks74u__sfw_g',
+              b'c_aks74u__shw_g', b'c_aks74u__sw_g', b'c_ammb__kw_g', b'c_ammb__sfw_g', b'c_ammb__shw_g',
+              b'c_ammb__sw_g', b'c_an94__kw_g', b'c_an94__sfw_g', b'c_an94__shw_g', b'c_an94__sw_g', b'c_as__da_g',
+              b'c_atm__kw_g', b'c_atm__sfw_g', b'c_atm__shw_g', b'c_atm__sw_g', b'c_aug__kw_g', b'c_aug__sfw_g',
+              b'c_aug__shw_g', b'c_aug__sw_g', b'c_bmd3__ddw_g', b'c_bmd3__si_g', b'c_bmda__ddw_g', b'c_bmda__si_g',
+              b'c_boaw__kw_g', b'c_br40mmgl_40mmgl__kw_g', b'c_br40mmsg_40mmsg__kw_g', b'c_br9a91_9a91__kw_g',
+              b'c_braek_aek__kw_g', b'c_brair__air_ki_g', b'c_brak47v_ak47v__kw_g', b'c_braks74u_aks74u__kw_g',
+              b'c_bran94_an94__kw_g', b'c_brarm__arm_ki_g', b'c_bratm_atm__kw_g', b'c_braug_aug__kw_g',
+              b'c_brc4_c4__kw_g', b'c_brf2000_f2000__kw_g', b'c_brg3_g3__kw_g', b'c_brgol_gol__kw_g',
+              b'c_brhgr_hgr__kw_g', b'c_brm136_m136__kw_g', b'c_brm16_m16__kw_g', b'c_brm16a1v_m16a1v__kw_g',
+              b'c_brm16k_m16k__kw_g', b'c_brm1911_m1911__kw_g', b'c_brm1_m1__kw_g', b'c_brm1a1_m1a1__kw_g',
+              b'c_brm21v_m21v__kw_g', b'c_brm249_m249__kw_g', b'c_brm24_m24__kw_g', b'c_brm2cg_m2cg__kw_g',
+              b'c_brm2v_m2v__kw_g', b'c_brm40v_m40v__kw_g', b'c_brm416_m416__kw_g', b'c_brm60_m60__kw_g',
+              b'c_brm60v_m60v__kw_g', b'c_brm93r_m93r__kw_g', b'c_brm95_m95__kw_g', b'c_brm95k_m95k__kw_g',
+              b'c_brm9_m9__kw_g', b'c_brmac10v_mac10v__kw_g', b'c_brmcs_mcs__kw_g', b'c_brmel_mel__kw_g',
+              b'c_brmg36_mg36__kw_g', b'c_brmg3_mg3__kw_g', b'c_brmg3k_mg3k__kw_g', b'c_brmk14ebr_mk14ebr__kw_g',
+              b'c_brmp412_mp412__kw_g', b'c_brmst_mst__kw_g', b'c_brn2k_n2k__kw_g', b'c_brpkm_pkm__kw_g',
+              b'c_brpp2_pp2__kw_g', b'c_brppshv_ppshv__kw_g', b'c_brqbu88_qbu88__kw_g', b'c_brqju88_qju88__kw_g',
+              b'c_brrpg7_rpg7__kw_g', b'c_brrpkv_rpkv__kw_g', b'c_brs12k_s12k__kw_g', b'c_brscar_scar__kw_g',
+              b'c_brsea__sea_ki_g', b'c_brspas12_spas12__kw_g', b'c_brstav__stav_ki_g', b'c_brsv98_sv98__kw_g',
+              b'c_brsvdv_svdv__kw_g', b'c_brsvu_svu__kw_g', b'c_brtt33v_tt33v__kw_g', b'c_brtveh__tveh_ki_g',
+              b'c_bru12_u12__kw_g', b'c_brump_ump__kw_g', b'c_brumpk_umpk__kw_g', b'c_bruzi_uzi__kw_g',
+              b'c_brvss_vss__kw_g', b'c_brxm22v_xm22v__kw_g', b'c_brxm8_xm8__kw_g', b'c_brxm8c_xm8c__kw_g',
+              b'c_brxm8lmg_xm8lmg__kw_g', b'c_c4__kw_g', b'c_c4__sfw_g', b'c_c4__shw_g', b'c_c4__sw_g', b'c_cav__ddw_g',
+              b'c_cav__si_g', b'c_cobr__ddw_g', b'c_cobr__si_g', b'c_de__da_g', b'c_defi__kw_g', b'c_defi__sfw_g',
+              b'c_defi__shw_g', b'c_defi__sw_g', b'c_deml__kw_g', b'c_f2000__kw_g', b'c_f2000__sfw_g',
+              b'c_f2000__shw_g', b'c_f2000__sw_g', b'c_g3__kw_g', b'c_g3__sfw_g', b'c_g3__shw_g', b'c_g3__sw_g',
+              b'c_gol__kw_g', b'c_gol__sfw_g', b'c_gol__shw_g', b'c_gol__sw_g', b'c_gaz69v__ddw_g', b'c_gaz69v__si_g',
+              b'c_go40mmgl_40mmgl__kw_g', b'c_go40mmsg_40mmsg__kw_g', b'c_go9a91_9a91__kw_g', b'c_goaek_aek__kw_g',
+              b'c_goair__air_ki_g', b'c_goak47v_ak47v__kw_g', b'c_goaks74u_aks74u__kw_g', b'c_goan94_an94__kw_g',
+              b'c_goarm__arm_ki_g', b'c_goatm_atm__kw_g', b'c_goaug_aug__kw_g', b'c_goc4_c4__kw_g',
+              b'c_gof2000_f2000__kw_g', b'c_gog3_g3__kw_g', b'c_gogol_gol__kw_g', b'c_gohgr_hgr__kw_g', b'c_gol__kw_g',
+              b'c_gol__sfw_g', b'c_gol__shw_g', b'c_gol__sw_g', b'c_gom136_m136__kw_g', b'c_gom16_m16__kw_g',
+              b'c_gom16a1v_m16a1v__kw_g', b'c_gom16k_m16k__kw_g', b'c_gom1911_m1911__kw_g', b'c_gom1_m1__kw_g',
+              b'c_gom1a1_m1a1__kw_g', b'c_gom21v_m21v__kw_g', b'c_gom249_m249__kw_g', b'c_gom24_m24__kw_g',
+              b'c_gom2cg_m2cg__kw_g', b'c_gom2v_m2v__kw_g', b'c_gom40v_m40v__kw_g', b'c_gom416_m416__kw_g',
+              b'c_gom60_m60__kw_g', b'c_gom60v_m60v__kw_g', b'c_gom93r_m93r__kw_g', b'c_gom95_m95__kw_g',
+              b'c_gom95k_m95k__kw_g', b'c_gom9_m9__kw_g', b'c_gomac10v_mac10v__kw_g', b'c_gomcs_mcs__kw_g',
+              b'c_gomel_mel__kw_g', b'c_gomg36_mg36__kw_g', b'c_gomg3_mg3__kw_g', b'c_gomg3k_mg3k__kw_g',
+              b'c_gomk14ebr_mk14ebr__kw_g', b'c_gomp412_mp412__kw_g', b'c_gomst_mst__kw_g', b'c_gon2k_n2k__kw_g',
+              b'c_gopkm_pkm__kw_g', b'c_gopp2_pp2__kw_g', b'c_goppshv_ppshv__kw_g', b'c_goqbu88_qbu88__kw_g',
+              b'c_goqju88_qju88__kw_g', b'c_gorpg7_rpg7__kw_g', b'c_gorpkv_rpkv__kw_g', b'c_gos12k_s12k__kw_g',
+              b'c_goscar_scar__kw_g', b'c_gosea__sea_ki_g', b'c_gospas12_spas12__kw_g', b'c_gostav__stav_ki_g',
+              b'c_gosv98_sv98__kw_g', b'c_gosvdv_svdv__kw_g', b'c_gosvu_svu__kw_g', b'c_gott33v_tt33v__kw_g',
+              b'c_gotveh__tveh_ki_g', b'c_gou12_u12__kw_g', b'c_goump_ump__kw_g', b'c_goumpk_umpk__kw_g',
+              b'c_gouzi_uzi__kw_g', b'c_govss_vss__kw_g', b'c_goxm22v_xm22v__kw_g', b'c_goxm8_xm8__kw_g',
+              b'c_goxm8c_xm8c__kw_g', b'c_goxm8lmg_xm8lmg__kw_g', b'c_havoc__ddw_g', b'c_havoc__si_g', b'c_helw__kw_g',
+              b'c_hgr__kw_g', b'c_hgr__sfw_g', b'c_hgr__shw_g', b'c_hgr__sw_g', b'c_hmv__ddw_g', b'c_hmv__si_g',
+              b'c_hueyv__ddw_g', b'c_hueyv__si_g', b'c_i01___hsh_g', b'c_i02_hg__kw_g', b'c_i03_hgr__kw_g',
+              b'c_i04_mel__kw_g', b'c_i05_mel__kw_g', b'c_i06___d_g', b'c_i07_ass__kw_g', b'c_i08_sup__kw_g',
+              b'c_i09___vd_g', b'c_i10___tag_g', b'c_i11___kn_g', b'c_i11___nik_g', b'c_i12_re_rec_lrh_g',
+              b'c_i13_c4__kw_g', b'c_i14_rec__kw_g', b'c_i15_dem__kw_g', b'c_i16___h_g', b'c_i17___res_g',
+              b'c_i18___msa_g', b'c_i19___r_g', b'c_i20___ko_g', b'c_i23_spe__kw_g', b'c_i24_atm__kw_g',
+              b'c_i25___dok_g', b'c_i26___hsh_g', b'c_i27___sa_g', b'c_i28___sa_g', b'c_i29___sa_g', b'c_i30___fc_g',
+              b'c_i31___bd_g', b'c_i38_mst__kw_g', b'c_i43___sqs_g', b'c_i44___sqres_g', b'c_i45___sqrep_g',
+              b'c_i46___sqh_g', b'c_i46___sqrev_g', b'c_i47___sqmsa_g', b'c_i48___ss_g', b'c_i49___sqa_g',
+              b'c_i49___sqs_g', b'c_i50___sqaob_g', b'c_i50___sqdob_g', b'c_jets__ddw_g', b'c_jets__si_g',
+              b'c_knv__kw_g', b'c_knv__sfw_g', b'c_knv__shw_g', b'c_knv__sw_g', b'c_kuro__ddw_g', b'c_kuro__si_g',
+              b'c_loss_att_out_g', b'c_loss_def_out_g', b'c_m136__kw_g', b'c_m136__sfw_g', b'c_m136__shw_g',
+              b'c_m136__sw_g', b'c_m14v__sw_g', b'c_m15v__ddw_g', b'c_m15v__si_g', b'c_m16__kw_g', b'c_m16__sfw_g',
+              b'c_m16__shw_g', b'c_m16__sw_g', b'c_m16a1v__kw_g', b'c_m16a1v__sfw_g', b'c_m16a1v__shw_g',
+              b'c_m16a1v__sw_g', b'c_m16k__kw_g', b'c_m16k__sfw_g', b'c_m16k__shw_g', b'c_m16k__sw_g', b'c_m1911__kw_g',
               b'c_m1911__sfw_g', b'c_m1911__shw_g', b'c_m1911__sw_g', b'c_m1__kw_g', b'c_m1__sfw_g', b'c_m1__shw_g',
               b'c_m1__sw_g', b'c_m1a1__kw_g', b'c_m1a1__sfw_g', b'c_m1a1__shw_g', b'c_m1a1__sw_g', b'c_m1a2__ddw_g',
               b'c_m1a2__si_g', b'c_m21v__kw_g', b'c_m21v__sfw_g', b'c_m21v__shw_g', b'c_m21v__sw_g', b'c_m249__kw_g',
